@@ -2,7 +2,7 @@
 
 package HPC::Runner::GnuParallel;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use DateTime;
 use DateTime::Format::Duration;
@@ -81,7 +81,8 @@ has 'command' => (
 
 has 'seq' => (
     is => 'rw',
-    isa => 'Int'
+    isa => 'Int',
+    default => 1,
 );
 
 =head2 go
